<?php
/**
 * Batch operations for news_client sync process.
 */

/**
 * Sync a cached article.
 */
function news_client_batch_sync_cached_article($nid, &$context) {
  if (!isset($context['sandbox']['progress'])) {
    $context['sandbox']['progress'] = 0;
  }
  
  // Update progress info.
  $context['sandbox']['progress']++;
  $context['message'] = t('Now processing nid %nid', array('%nid' => $nid));
  
  $site_identifiers = variable_get('news_client_site_identifiers');
  
  $cached_article = entity_load_single('node', $nid);
  
  try {
    $ca_wrapper = entity_metadata_wrapper('node', $cached_article);
    $news_service_id = $ca_wrapper->news_client_news_service_nid->value();
  }
  catch (Exception $e) {
    _news_client_entitymetadatawrapper_exception($e);
  }
  
  $article = _news_client_fetch_article($news_service_id, $site_identifiers);
  
  if (is_null($article)) {
    // Most likely a request failure.
    $context['results'][] = t('Processing failed for %nid. (Potential request failure)', array('%nid' => $nid));
  }
  else if (empty($article)) {
    // Most likely article doesn't exist, or no longer exists for the sites.
    entity_delete('node', $cached_article->nid);
    
    $context['results'][] = t('Deleted %nid. (%title)', array('%nid' => $nid, '%title' => $cached_article->title));
  }
  else {
    // More than likely still a valid article.
    $synced_article = _news_client_cached_article_populate($article);
    
    $context['results'][] = t('Sync complete for %nid. (%title)', array('%nid' => $nid, '%title' => $synced_article->title));
  }
}

/**
 * Finish callback for news_client batch sync.
 */
function news_client_batch_sync_finished($success, $results, $operations) {
  if ($success) {
    // Here we do something meaningful with the results.
    $message = t('@count items successfully processed:', array('@count' => count($results)));
    $message .= theme('item_list', array('items' => $results));
    drupal_set_message($message);
  }
  else {
    // An error occurred.
    // $operations contains the operations that remained unprocessed.
    $error_operation = reset($operations);
    $message = t('An error occurred while processing %error_operation with arguments: @arguments', array('%error_operation' => $error_operation[0], '@arguments' => print_r($error_operation[1], TRUE)));
    drupal_set_message($message, 'error');
  }
}
